@@ -3,16 +3,12 @@
 #' `validation_split()` takes a single random sample (without replacement) of
 #'  the original data set to be used for analysis. All other data points are
 #'  added to the assessment set (to be used as the validation set).
-#' @details The `strata` argument causes the random sampling to be conducted
-#'  *within the stratification variable*. This can help ensure that the number of
-#'  data points in the analysis data is equivalent to the proportions in the
-#'  original data set. (Strata below 10% of the total are pooled together.)
+#'  `validation_time_split()` does the same, but takes the _first_ `prop` samples
+#'  for training, instead of a random selection.
+#' @template strata_details
 #' @inheritParams vfold_cv
 #' @inheritParams make_strata
 #' @param prop The proportion of data to be retained for modeling/analysis.
-#' @param strata A variable that is used to conduct stratified sampling to
-#'  create the resamples. This could be a single character value or a variable
-#'  name that corresponds to a variable that exists in the data frame.
 #' @export
 #' @return An tibble with classes `validation_split`, `rset`, `tbl_df`, `tbl`,
 #'  and `data.frame`. The results include a column for the data split objects
@@ -20,6 +16,9 @@
 #'  identifier.
 #' @examples
 #' validation_split(mtcars, prop = .9)
+#'
+#' data(drinks, package = "modeldata")
+#' validation_time_split(drinks)
 #' @export
 validation_split <- function(data, prop = 3/4,
                              strata = NULL, breaks = 4, pool = 0.1, ...) {
@@ -56,6 +55,41 @@ validation_split <- function(data, prop = 3/4,
            subclass = c("validation_split", "rset"))
 }
 
+#' @rdname validation_split
+#' @inheritParams vfold_cv
+#' @inheritParams initial_time_split
+#' @export
+validation_time_split <- function(data, prop = 3/4, lag = 0, ...) {
+
+  if (!is.numeric(prop) | prop >= 1 | prop <= 0) {
+    rlang::abort("`prop` must be a number on (0, 1).")
+  }
+
+  if (!is.numeric(lag) | !(lag%%1 == 0)) {
+    stop("`lag` must be a whole number.", call. = FALSE)
+  }
+
+  n_train <- floor(nrow(data) * prop)
+
+  if (lag > n_train) {
+    stop("`lag` must be less than or equal to the number of training observations.", call. = FALSE)
+  }
+
+  split  <- rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
+  split <- rm_out(split)
+  class(split) <- c("val_split", "rsplit")
+  splits <- list(split)
+
+  val_att <- list(prop = prop, strata = FALSE)
+
+  new_rset(splits = splits,
+           ids = "validation",
+           attrib = val_att,
+           subclass = c("validation_split", "rset"))
+
+}
+
+
 #' @export
 print.validation_split <- function(x, ...) {
   cat("#", pretty(x), "\n")
